<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="101"/>
        <source>MX Package Installer</source>
        <translation>MX Instalador de paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Aplicativos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Información</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="468"/>
        <location filename="../mainwindow.ui" line="660"/>
        <location filename="../mainwindow.ui" line="1030"/>
        <source>Description</source>
        <translation>Descrición</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="191"/>
        <location filename="../mainwindow.ui" line="730"/>
        <location filename="../mainwindow.ui" line="1055"/>
        <location filename="../mainwindow.ui" line="1274"/>
        <source>search</source>
        <translation>busca</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="204"/>
        <location filename="../mainwindow.ui" line="772"/>
        <location filename="../mainwindow.ui" line="1118"/>
        <location filename="../mainwindow.ui" line="1245"/>
        <source>= Installed packages</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Enabled Repos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="237"/>
        <source>Remove orphan packages</source>
        <translation>Eliminar paquetes orfos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="264"/>
        <location filename="../mainwindow.ui" line="1337"/>
        <source>Upgrade All</source>
        <translation>Actualizar todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="278"/>
        <location filename="../mainwindow.ui" line="558"/>
        <location filename="../mainwindow.ui" line="886"/>
        <source>Installed:</source>
        <translation>Instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="301"/>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="907"/>
        <source>Total packages:</source>
        <translation>Total de paquetes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="315"/>
        <location filename="../mainwindow.ui" line="615"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Tamén instale os paquetes &quot;Recomendados&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="322"/>
        <location filename="../mainwindow.ui" line="588"/>
        <location filename="../mainwindow.ui" line="879"/>
        <source>Upgradable:</source>
        <translation>Actualizables:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="329"/>
        <location filename="../mainwindow.ui" line="522"/>
        <location filename="../mainwindow.ui" line="914"/>
        <source>Hide library and developer packages</source>
        <translation>Agochar paquetes de bibliotecas e de desenvolvedor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="351"/>
        <location filename="../mainwindow.ui" line="544"/>
        <location filename="../mainwindow.ui" line="966"/>
        <source>Refresh list</source>
        <translation>Recargar a lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="390"/>
        <location filename="../mainwindow.ui" line="688"/>
        <location filename="../mainwindow.ui" line="1085"/>
        <location filename="../mainwindow.ui" line="1197"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrar paquetes polo estado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="393"/>
        <location filename="../mainwindow.ui" line="397"/>
        <location filename="../mainwindow.ui" line="691"/>
        <location filename="../mainwindow.ui" line="695"/>
        <location filename="../mainwindow.ui" line="1088"/>
        <location filename="../mainwindow.ui" line="1092"/>
        <location filename="../mainwindow.cpp" line="2555"/>
        <source>All packages</source>
        <translation>Todos os paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="402"/>
        <location filename="../mainwindow.ui" line="700"/>
        <location filename="../mainwindow.ui" line="1097"/>
        <location filename="../mainwindow.cpp" line="2568"/>
        <source>Installed</source>
        <translation>Instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="407"/>
        <location filename="../mainwindow.ui" line="705"/>
        <location filename="../mainwindow.ui" line="1102"/>
        <location filename="../mainwindow.cpp" line="2566"/>
        <source>Upgradable</source>
        <translation>Actualizables</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="412"/>
        <location filename="../mainwindow.ui" line="710"/>
        <location filename="../mainwindow.ui" line="1107"/>
        <location filename="../mainwindow.ui" line="1234"/>
        <location filename="../mainwindow.cpp" line="2540"/>
        <location filename="../mainwindow.cpp" line="2571"/>
        <location filename="../mainwindow.cpp" line="2663"/>
        <location filename="../mainwindow.cpp" line="2664"/>
        <source>Not installed</source>
        <translation>Non instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="432"/>
        <location filename="../mainwindow.ui" line="752"/>
        <location filename="../mainwindow.ui" line="814"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="458"/>
        <location filename="../mainwindow.ui" line="650"/>
        <location filename="../mainwindow.ui" line="1020"/>
        <source>Package Name</source>
        <translation>Nome do paquete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="463"/>
        <location filename="../mainwindow.ui" line="655"/>
        <location filename="../mainwindow.ui" line="1025"/>
        <location filename="../mainwindow.ui" line="1469"/>
        <source>Version</source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <source>MX Test Repo</source>
        <translation>Repositorio de proba de MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="796"/>
        <source>Debian Backports</source>
        <translation>Debian Backports</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1142"/>
        <source>Flatpaks</source>
        <translation>Paquetes flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1148"/>
        <location filename="../mainwindow.ui" line="1152"/>
        <source>For all users</source>
        <translation>Para todos os usuarios</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1157"/>
        <source>For current user</source>
        <translation>Para o actual usuario</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1165"/>
        <source>Remote (repo):</source>
        <translation>(Repositorio) remoto:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1200"/>
        <location filename="../mainwindow.ui" line="1204"/>
        <location filename="../mainwindow.cpp" line="2522"/>
        <source>All apps</source>
        <translation>Aplicativos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1209"/>
        <location filename="../mainwindow.cpp" line="2526"/>
        <source>All runtimes</source>
        <translation>Software &apos;runtime&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1214"/>
        <location filename="../mainwindow.cpp" line="2530"/>
        <source>All available</source>
        <translation>Todo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1219"/>
        <location filename="../mainwindow.cpp" line="2520"/>
        <source>Installed apps</source>
        <translation>Aplicativos instaladas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1224"/>
        <location filename="../mainwindow.cpp" line="2518"/>
        <source>Installed runtimes</source>
        <translation>Software &apos;runtime&apos; instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1229"/>
        <location filename="../mainwindow.cpp" line="2538"/>
        <location filename="../mainwindow.cpp" line="2657"/>
        <location filename="../mainwindow.cpp" line="2658"/>
        <source>All installed</source>
        <translation>Todos instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1316"/>
        <source>Total items </source>
        <translation>Total de items</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1330"/>
        <source>Installed apps:</source>
        <translation>Aplicativos instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1383"/>
        <source>Advanced</source>
        <translation>Avanzado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1413"/>
        <source>Total installed size:</source>
        <translation>Total instalado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1427"/>
        <source>Remove unused runtimes</source>
        <translation>Elimina os tempos de execución non utilizados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1459"/>
        <source>Short Name</source>
        <translation>Nome curto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1464"/>
        <source>Full Package Name</source>
        <translation>Nome completo do paquete</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1474"/>
        <source>Size</source>
        <translation>Tamaño</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1504"/>
        <location filename="../mainwindow.cpp" line="2329"/>
        <location filename="../mainwindow.cpp" line="2478"/>
        <source>Console Output</source>
        <translation>Procesamento en consola</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1510"/>
        <source>Enter</source>
        <translation>Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1521"/>
        <source>Respond here, or just press Enter</source>
        <translation>Responder aquí ou premer enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1577"/>
        <location filename="../mainwindow.cpp" line="1087"/>
        <location filename="../mainwindow.cpp" line="2650"/>
        <location filename="../mainwindow.cpp" line="2654"/>
        <location filename="../mainwindow.cpp" line="2912"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1584"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1603"/>
        <source>Quit application</source>
        <translation>Saír do aplicativo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1606"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1613"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1645"/>
        <source>About this application</source>
        <translation>Sobre esta aplicación</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1648"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1655"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1693"/>
        <source>Display help </source>
        <translation>Amosar axuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1696"/>
        <source>Help</source>
        <translation>Axuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1703"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1719"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1726"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="92"/>
        <source>Flatpak tab is disabled on 32-bit.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="184"/>
        <source>Uninstalling packages...</source>
        <translation>Desinstalando paquetes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Running pre-uninstall operations...</source>
        <translation>Realizando operacións previas á desinstalación...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="208"/>
        <source>Running post-uninstall operations...</source>
        <translation>Executando operacions despois de desinstalar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="223"/>
        <source>Refreshing sources...</source>
        <translation>Actualizando as orixes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="236"/>
        <location filename="../mainwindow.cpp" line="1133"/>
        <location filename="../mainwindow.cpp" line="1263"/>
        <location filename="../mainwindow.cpp" line="1405"/>
        <location filename="../mainwindow.cpp" line="1466"/>
        <location filename="../mainwindow.cpp" line="2144"/>
        <location filename="../mainwindow.cpp" line="2175"/>
        <location filename="../mainwindow.cpp" line="2187"/>
        <location filename="../mainwindow.cpp" line="2302"/>
        <location filename="../mainwindow.cpp" line="2321"/>
        <location filename="../mainwindow.cpp" line="2378"/>
        <location filename="../mainwindow.cpp" line="2395"/>
        <location filename="../mainwindow.cpp" line="2412"/>
        <location filename="../mainwindow.cpp" line="2733"/>
        <location filename="../mainwindow.cpp" line="2809"/>
        <location filename="../mainwindow.cpp" line="2840"/>
        <location filename="../mainwindow.cpp" line="2936"/>
        <location filename="../mainwindow.cpp" line="2960"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="237"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Houbo un problema ao actualizar as orixes. Algunhas orixes poden non ter fornecido actualizacións. Para máis información, ver:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="641"/>
        <source>Please wait...</source>
        <translation>Agarda...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="822"/>
        <location filename="../mainwindow.cpp" line="840"/>
        <source>Version </source>
        <translation>Versión </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="823"/>
        <source> in the enabled repos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="825"/>
        <source>Not available in the enabled repos</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="834"/>
        <location filename="../mainwindow.cpp" line="2455"/>
        <source>Latest version </source>
        <translation>última versión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="834"/>
        <location filename="../mainwindow.cpp" line="2455"/>
        <source> already installed</source>
        <translation>Xa está instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="840"/>
        <source> installed</source>
        <translation>instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="952"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>O repositório MX Test, cuxos paquetes son dispoñibilizados só para efecto de probar, está para ser usado. Os paquetes deste repositorio poden damnificar o sistema, polo que se suxire que sexa feita unha copia de seguranza do mesmo e que sexa instalado ou actualizado só un paquete de cada vez. Agradécese que os resultados sexan comunicados no foro, para que haxa unha avalición dos paquetes antes de seren movidos para o repositorio principal.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="961"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Será usado o repositorio &apos;Debian Backports&apos;, que contén paquetes retirados da versión (chamada &apos;testing&apos;) de Debian, adaptados e recompilados para uso na actual versión estable de Debian, sendo por isto designados paquetes retro-portados. Estes paquetes non foron tan extensivamente probados como os das versións estables de Debian e de MX; son dispoñibilizados &apos;como están&apos;, co risco de incompatibilidades con outros compoñentes de Debian &apos;estable&apos;. Usar con coidado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="969"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>O MX inclúe este repositorio de paquetes flatpak só para conveniencia dos usuarios, non sendo responsable polo funcionamento dos propios paquetes flatpak. Para máis información, consultar &apos;flatpaks&apos; na Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="976"/>
        <location filename="../mainwindow.cpp" line="2946"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="980"/>
        <source>Do not show this message again</source>
        <translation>Non amosar esta mensaxe de novo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1085"/>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1099"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Seleccionáronse os seguintes paquetes. Preme en Amosar detalles para ver a lista de cambios.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1134"/>
        <location filename="../mainwindow.cpp" line="1264"/>
        <location filename="../mainwindow.cpp" line="1467"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Sen conexión a Internet; non é posible descargar a lista de paquetes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1137"/>
        <source>Installing packages...</source>
        <translation>Instalando paquetes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1196"/>
        <source>Post-processing...</source>
        <translation>Posprocesando...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1226"/>
        <source>Pre-processing for </source>
        <translation>Prepocesando para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1240"/>
        <source>Installing </source>
        <translation>Instalando</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1247"/>
        <source>Post-processing for </source>
        <translation>Posprocesando para</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1406"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Produciuse un erro ao escribir o ficheiro: %1. Comproba se tes espazo libre suficiente na túa unidade</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1475"/>
        <source>Downloading package info...</source>
        <translation>Descargando información do paquete...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1933"/>
        <location filename="../mainwindow.cpp" line="2008"/>
        <location filename="../mainwindow.cpp" line="2032"/>
        <source>Package info</source>
        <translation>Información do paquete</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1945"/>
        <location filename="../mainwindow.cpp" line="2878"/>
        <source>More &amp;info...</source>
        <translation>Máis &amp;información...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1974"/>
        <source>Packages to be installed: </source>
        <translation>Paquetes instalándose:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2140"/>
        <location filename="../mainwindow.cpp" line="2153"/>
        <location filename="../mainwindow.cpp" line="2169"/>
        <location filename="../mainwindow.cpp" line="2184"/>
        <location filename="../mainwindow.cpp" line="2273"/>
        <location filename="../mainwindow.cpp" line="2297"/>
        <location filename="../mainwindow.cpp" line="2729"/>
        <location filename="../mainwindow.cpp" line="2803"/>
        <location filename="../mainwindow.cpp" line="2834"/>
        <location filename="../mainwindow.cpp" line="2930"/>
        <source>Done</source>
        <translation>Feito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2140"/>
        <location filename="../mainwindow.cpp" line="2153"/>
        <location filename="../mainwindow.cpp" line="2169"/>
        <location filename="../mainwindow.cpp" line="2184"/>
        <location filename="../mainwindow.cpp" line="2273"/>
        <location filename="../mainwindow.cpp" line="2297"/>
        <location filename="../mainwindow.cpp" line="2315"/>
        <location filename="../mainwindow.cpp" line="2729"/>
        <location filename="../mainwindow.cpp" line="2803"/>
        <location filename="../mainwindow.cpp" line="2834"/>
        <location filename="../mainwindow.cpp" line="2930"/>
        <location filename="../mainwindow.cpp" line="2954"/>
        <source>Processing finished successfully.</source>
        <translation>Procesamento rematado con éxito.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2145"/>
        <location filename="../mainwindow.cpp" line="2176"/>
        <location filename="../mainwindow.cpp" line="2188"/>
        <location filename="../mainwindow.cpp" line="2734"/>
        <location filename="../mainwindow.cpp" line="2810"/>
        <location filename="../mainwindow.cpp" line="2841"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Detectado problema ao instalar; verificar información na consola. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2198"/>
        <source>About %1</source>
        <translation>Sobre %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2199"/>
        <source>Version: </source>
        <translation>Versión</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2201"/>
        <source>Package Installer for MX Linux</source>
        <translation>Xestor de paquetes de MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2203"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2204"/>
        <source>%1 License</source>
        <translation>Licenza de %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2217"/>
        <source>%1 Help</source>
        <translation>Axuda para %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2302"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Foi atopado un problema ao desinstalar. Verificar os resultados.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2315"/>
        <location filename="../mainwindow.cpp" line="2954"/>
        <source>Success</source>
        <translation>Con éxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2321"/>
        <location filename="../mainwindow.cpp" line="2960"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Houbo un problema ao desinstalar o programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2379"/>
        <location filename="../mainwindow.cpp" line="2396"/>
        <location filename="../mainwindow.cpp" line="2413"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2429"/>
        <location filename="../mainwindow.cpp" line="2441"/>
        <source>Flatpak not installed</source>
        <translation>Paquete flatpak non instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2430"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>O paquete flatpak non está instalado.
Continuar e instalar o paquete?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2441"/>
        <source>Flatpak was not installed</source>
        <translation>O paquete flatpak non estaba instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2465"/>
        <location filename="../mainwindow.cpp" line="2487"/>
        <source>Flathub remote failed</source>
        <translation>Fallo no repositotio remoto Flathub</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2465"/>
        <location filename="../mainwindow.cpp" line="2487"/>
        <source>Flathub remote could not be added</source>
        <translation>Non foi posible engadir o repositorio remoto Flathub</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2473"/>
        <source>Needs re-login</source>
        <translation>É necesario volver a iniciar sesió</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2474"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Poderá ser necesario saír e volver a iniciar sesión para ue os items queden visibles no menú</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2650"/>
        <source>Upgrade</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2762"/>
        <source>Quit?</source>
        <translation>Saír?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2763"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>O proceso aínda está en execución. Saír pode deixar o sistema nun estado instable.&lt;p&gt;&lt;b&gt;Saír realmente do MX instalador de paquetes?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2910"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2937"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Detectouse un problema durante a última operación. Inspeccione a saída da consola.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2947"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Operación potencialmente perigosa.
Asegúrate de comprobar coidadosamente a lista de paquetes a eliminar.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="13"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Xestionar repositorios remotos flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="22"/>
        <source>For all users</source>
        <translation>Para todos os usuarios</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For current user</source>
        <translation>Para o actual usuario</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="29"/>
        <source>enter Flatpak remote URL</source>
        <translation>introducir o URL do repositorio remoto flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="32"/>
        <source>enter Flatpakref location to install app</source>
        <translation>para instalar un aplicativo, introducir a localización do respectivo ficheiro .flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="34"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Engadir ou eliminar repositorios remotos flatpak ou instalr aplicativos usando o URL ou o camiño para o respectivo ficheiro .flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="43"/>
        <source>Remove remote</source>
        <translation>Eliminar repositorio remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="48"/>
        <source>Add remote</source>
        <translation>Engadir repositorio remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="53"/>
        <source>Install app</source>
        <translation>Instalar aplicativo</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="58"/>
        <source>Close</source>
        <translation>Cerrar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="75"/>
        <source>Not removable</source>
        <translation>Non se pode eliminar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="76"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>O Flathub é o principal repositorio remoto flatpak e non será eliminado</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="96"/>
        <source>Error adding remote</source>
        <translation>Erro ao engadir o repositorio remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="97"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Non é posible engadir o repositorio remoto - o comando resultou un erro. Verificar o enderezo do repositorio remoto e volver a intentar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Success</source>
        <translation>Con éxito</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Remote added successfully</source>
        <translation>Repositorio remoto engadido con éxito</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="52"/>
        <source>License</source>
        <translation>Licenza</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Rexistro dos cambios</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="54"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="74"/>
        <source>&amp;Close</source>
        <translation>&amp;Cerrar</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="82"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../main.cpp" line="92"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="93"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>O usuario parece ser root; para usar este programa, pechar a sesión e iniciar sesión como usuario normal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="103"/>
        <source>Unable to get exclusive lock</source>
        <translation>Non foi posible obter o bloqueo exclusivo</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="104"/>
        <source>Another package management application (like Synaptic or apt-get), is already running. Please close that application first</source>
        <translation>Está en execución outro aplicativo de xestión de paquetes (p. ex. Synaptic ou apt-get). Pechar primeiro o aplicativo.</translation>
    </message>
</context>
</TS>
